@@ -32,9 +32,9 @@ class AppMarble(Marble):
 
     def redirect(marble, **p):
         conversion = marble.ruleset.generate_url(p, marble.url_parts)
-        marble.bag.http.response.status = '301 Redirect' 
-        marble.bag.http.response.headers.append(('Location', str(conversion.result.url)))
-        marble.bag.http.response.body = ['Redirecting...']
+        marble.bag.http_response.status = '301 Redirect' 
+        marble.bag.http_response.header_list.append(dict(name='Location', value=str(conversion.result.url)))
+        marble.bag.http_response.body = ['Redirecting...']
         return 'Redirecting...'
 
 class BaseApp(MarblePipe):
@@ -122,11 +122,11 @@ class BaseApp(MarblePipe):
                     "environ SCRIPT_NAME: %r, url_parts path: %r"
                 ),
                 url_parts['script'], 
-                bag.http.environ.get('SCRIPT_NAME', ''), 
+                bag.environ.get('SCRIPT_NAME', ''), 
                 self.path,
             )
             url_parts['script'] = url_parts['script'][\
-               len(bag.http.environ.get('SCRIPT_NAME', '')):]\
+               len(bag.environ.get('SCRIPT_NAME', '')):]\
                + self.path.strip('/')
             url_parts['path'] = url_parts['path'][len(self.path)-1:]
         log.info('Modified URL Parts: %r', url_parts)
@@ -135,7 +135,7 @@ class BaseApp(MarblePipe):
             # Not for this URL.
             log.info(
                 'Could not route %r to an action, no URL vars found',
-                bag.http.environ['PATH_INFO'],
+                bag.environ['PATH_INFO'],
             )
             return
         res = conversion.result
@@ -153,7 +153,7 @@ class BaseApp(MarblePipe):
         if not vars.get('area'):
             log.info(
                 'Could not route %r to an action, no area specified',
-                bag.http.environ['PATH_INFO'],
+                bag.environ['PATH_INFO'],
             )
             return
         else:
@@ -213,7 +213,7 @@ class BaseApp(MarblePipe):
                     'The Python module in %r for area %r matched from %r '
                     'does not exist ',
                     app_dir, area_name, 
-                    bag.http.environ['PATH_INFO'],
+                    bag.environ['PATH_INFO'],
                 )
                 return
             # We support two types of area: modules and classes. 
@@ -244,7 +244,7 @@ class BaseApp(MarblePipe):
             log.info(
                 'Could not route %r to an action or API call, no action or '
                 'api specified by matched rule',
-                bag.http.environ['PATH_INFO'],
+                bag.environ['PATH_INFO'],
             )
             return
         elif vars.get('action'):
@@ -254,14 +254,14 @@ class BaseApp(MarblePipe):
                     'No such action %r in area %r matched from %r ',
                     action_name,
                     area_name,
-                    bag.http.environ['PATH_INFO'],
+                    bag.environ['PATH_INFO'],
                 )
                 return
             else: 
                 action = getattr(area, action_name)
                 result = action(marble)
                 if result is None:
-                    if bag.http.response.body:
+                    if bag.http_response.body:
                         log.info(
                             'No response from action but body present so '
                             'not raising an error'
@@ -272,9 +272,9 @@ class BaseApp(MarblePipe):
                         )
                 else:
                     if isinstance(result, (unicode, str)):
-                        bag.http.response.body = [result]
+                        bag.http_response.body = [result]
                     else:
-                        bag.http.response.body = result
+                        bag.http_response.body = result
                 bag.interrupt_flow(application_handled=True)
 
 class BaseArea(object):
